@@ -1,7 +1,7 @@
 <?php
 
 /*
- * Copyright (c) 2008 Guillaume Lelarge <guillaume@lelarge.info>
+ * Copyright (c) 2008-2010 Guillaume Lelarge <guillaume@lelarge.info>
  *
  * Permission to use, copy, modify, and distribute this software for any
  * purpose with or without fee is hereby granted, provided that the above
@@ -25,28 +25,30 @@ $buffer = $navigate_activities.'
 
 $query = "SELECT
   datname,
-  procpid,";
-if ($g_version > 80) {
-  $query .= "
-  client_addr,";
-}
-$query .= "
+  procpid,
   usename,
-  current_query,";
-if ($g_version >= 82) {
-  $query .= "
-  waiting,";
-}
-if ($g_version >= 83) {
-  $query .= "
-  date_trunc('second', xact_start) as xact_start,";
-}
-$query .="
+  current_query,
   date_trunc('second', query_start) as query_start";
 if ($g_version > 80) {
+  $query .= ",
+  client_addr";
+}
+if ($g_version >= 82) {
+  $query .= ",
+  waiting";
+}
+if ($g_version >= 83) {
+  $query .= ",
+  date_trunc('second', xact_start) as xact_start";
+}
+if ($g_version >= 82) {
 $query .= ",
   date_trunc('second', backend_start) as backend_start";
 }
+if ($g_version >= 90) {
+  $query .= ",
+  application_name";
+}
 $query .= "
 FROM pg_stat_activity
 ORDER BY datname, procpid";
@@ -63,6 +65,10 @@ $buffer .= '<div class="tblBasic">
 <tr>
   <th class="colFirst">DB name</th>
   <th class="colMid">PID</th>';
+if ($g_version >= 90) {
+  $buffer .= '
+  <th class="colMid">Application name</th>';
+}
 if ($g_version > 80) {
   $buffer .= '
   <th class="colMid">Client</th>';
@@ -73,49 +79,49 @@ if ($g_version >= 83) {
   $buffer .= '
   <th class="colMid">Waiting</th>';
 }
+if ($g_version >= 82) {
+  $buffer .= '
+  <th class="colMid">Backend start</th>';
+}
 if ($g_version >= 83) {
   $buffer .= '
   <th class="colMid">XACT start</th>';
 }
-if ($g_version > 80) {
-  $buffer .= '
-  <th class="colMid">Query start</th>';
-} else {
-  $buffer .= '
-  <th class="colMid">Query</th>';
-}
 $buffer .= '
-  <th class="colLast">Backend start</th>
+  <th class="colMid">Query start</th>
+  <th class="colLast">Query</th>
 </tr>
 ';
 
 while ($row = pg_fetch_array($rows)) {
 $buffer .= tr()."
-  <td>".$row['datname']."</td>
+  <td title=\"".$comments['databases'][$row['datname']]."\">".$row['datname']."</td>
   <td>".$row['procpid']."</td>";
+if ($g_version >= 90) {
+  $buffer .= "
+  <td>".$row['application_name']."</td>";
+}
 if ($g_version > 80) {
   $buffer .= "
   <td>".$row['client_addr']."</td>";
 }
 $buffer .= "
-  <td>".$row['usename']."</td>";
+  <td title=\"".$comments['roles'][$row['usename']]."\">".$row['usename']."</td>";
 if ($g_version >= 82) {
   $buffer .= "
   <td>".$image[$row['waiting']]."</td>";
 }
+if ($g_version >= 82) {
+  $buffer .= '
+  <td>'.$row['backend_start'].'</td>';
+}
 if ($g_version >= 83) {
   $buffer .= "
   <td>".$row['xact_start']."</td>";
 }
-if ($g_version > 80) {
-  $buffer .= '
-  <td title="'.$row['current_query'].'">'.$row['query_start'].'</td>';
-} else {
-  $buffer .= '
-  <td>'.$row['current_query'].'</td>';
-}
 $buffer .= '
-  <td>'.$row['backend_start'].'</td>
+  <td>'.$row['query_start'].'</td>
+  <td>'.$row['current_query'].'</td>
 </tr>';
 }
 
