@@ -1,7 +1,7 @@
 <?php
 
 /*
- * Copyright (c) 2008 Guillaume Lelarge <guillaume@lelarge.info>
+ * Copyright (c) 2008-2010 Guillaume Lelarge <guillaume@lelarge.info>
  *
  * Permission to use, copy, modify, and distribute this software for any
  * purpose with or without fee is hereby granted, provided that the above
@@ -23,7 +23,13 @@ $buffer = $navigate_globalobjects.'
 
 $query = 'SELECT datname,
   pg_get_userbyid(datdba) AS dba,
-  pg_catalog.pg_encoding_to_char(encoding) AS encoding,
+  pg_catalog.pg_encoding_to_char(encoding) AS encoding,';
+if ($g_version > 83) {
+  $query .= '
+  datcollate,
+  datctype,';
+}
+$query .= '
   datistemplate,
   datallowconn,';
 if ($g_version > 80) {
@@ -41,12 +47,29 @@ if ($g_version > 80) {
   $query .= '
   pg_size_pretty(pg_database_size(datname)) AS size,';
 }
+if ($g_version < 90) {
+  $query .= '
+    datconfig,';
+}
+$query .= '
+  datacl';
+if ($g_version > 81) {
+  $query .= ',
+  age(datfrozenxid) AS freezeage, ROUND(100*(age(datfrozenxid)/freez::float)) AS perc';
+}
 $query .= '
-  datconfig,
-  datacl
 FROM pg_database';
 if ($g_version > 74) {
-  $query .= ', pg_tablespace
+  $query .= ', pg_tablespace';
+}
+if ($g_version > 81) {
+  $query .= "
+JOIN (SELECT setting AS freez FROM pg_settings
+      WHERE name = 'autovacuum_freeze_max_age') AS param
+      ON (true)";
+}
+if ($g_version > 74) {
+  $query .= '
 WHERE dattablespace = pg_tablespace.oid';
 }
 $query .= '
@@ -64,7 +87,13 @@ $buffer .= '<div class="tblBasic">
 <tr>
   <th class="colFirst" width="200">DB Owner</th>
   <th class="colMid" width="200">DB Name</th>
-  <th class="colMid" width="200">Encoding</th>
+  <th class="colMid" width="200">Encoding</th>';
+if ($g_version > 83) {
+  $buffer .= '
+  <th class="colMid" width="100">Collation</th>
+  <th class="colMid" width="100">CType</th>';
+}
+$buffer .= '
   <th class="colMid" width="100">Template?</th>
   <th class="colMid" width="100">Allow connections?</th>';
 if ($g_version > 80) {
@@ -82,8 +111,15 @@ if ($g_version > 80) {
   $buffer .= '
   <th class="colMid" width="200">Size</th>';
 }
+if ($g_version > 81) {
+  $buffer .= '
+  <th class="colMid" width="200">Auto Freeze</th>';
+}
+if ($g_version < 90) {
+  $buffer .= '
+  <th class="colMid" width="200">Configuration</th>';
+}
 $buffer .= '
-  <th class="colMid" width="200">Configuration</th>
   <th class="colLast" width="300"><acronym title="Access Control List">ACL</acronym></th>
 </tr>
 </thead>
@@ -91,9 +127,15 @@ $buffer .= '
 
 while ($row = pg_fetch_array($rows)) {
 $buffer .= tr().'
-  <td>'.$row['dba'].'</td>
-  <td>'.$row['datname'].'</td>
-  <td>'.$row['encoding'].'</td>
+  <td title="'.$comments['roles'][$row['dba']].'">'.$row['dba'].'</td>
+  <td title="'.$comments['databases'][$row['datname']].'">'.$row['datname'].'</td>
+  <td>'.$row['encoding'].'</td>';
+if ($g_version > 83) {
+  $buffer .= '
+  <td>'.$row['datcollate'].'</td>
+  <td>'.$row['datctype'].'</td>';
+}
+$buffer .= '
   <td>'.$image[$row['datistemplate']].'</td>
   <td>'.$image[$row['datallowconn']].'</td>';
 if ($g_version > 80) {
@@ -105,14 +147,21 @@ $buffer .= '
   <td>'.$row['datfrozenxid'].'</td>';
 if ($g_version > 74) {
   $buffer .= '
-  <td>'.$row['tablespace'].'</td>';
+  <td title="'.$comments['tablespaces'][$row['tablespace']].'">'.$row['tablespace'].'</td>';
 }
 if ($g_version > 80) {
   $buffer .= '
   <td>'.$row['size'].'</td>';
 }
+if ($g_version > 81) {
+  $buffer .= '
+  <td>'.$row['freezeage'].' ('.$row['perc'].' %)</td>';
+}
+if ($g_version < 90) {
+  $buffer .= '
+  <td>'.$row['datconfig'].'</td>';
+}
 $buffer .= '
-  <td>'.$row['datconfig'].'</td>
   <td><acronym X=\"Access Control List\">'.$row['datacl'].'</acronym></td>
 </tr>';
 }
