@@ -1,7 +1,7 @@
 <?php
 
 /*
- * Copyright (c) 2008 Guillaume Lelarge <guillaume@lelarge.info>
+ * Copyright (c) 2008-2010 Guillaume Lelarge <guillaume@lelarge.info>
  *
  * Permission to use, copy, modify, and distribute this software for any
  * purpose with or without fee is hereby granted, provided that the above
@@ -48,8 +48,8 @@ $buffer .= '<div class="tblBasic">
 
 while ($row = pg_fetch_array($rows)) {
 $buffer .= tr()."
-  <td>";
-if ($row['blks_read'] >= $row['blks_hit']) {
+  <td title=\"".$comments['databases'][$row['datname']]."\">";
+if ($row['blks_read'] >= $row['blks_hit'] && $row['blks_read']+$row['blks_hit'] > 0) {
   $buffer .= '<span class="txtImportant">';
 }
 $buffer .= $row['datname'];
