@@ -1,7 +1,7 @@
 <?php
 
 /*
- * Copyright (c) 2008 Guillaume Lelarge <guillaume@lelarge.info>
+ * Copyright (c) 2008-2010 Guillaume Lelarge <guillaume@lelarge.info>
  *
  * Permission to use, copy, modify, and distribute this software for any
  * purpose with or without fee is hereby granted, provided that the above
@@ -44,7 +44,7 @@ if ($g_passwordrequired && strlen($PGPASSWORD) == 0) {
     }
   }
   // if still no password
-  if (strlen($PGPASSWORD) == 0) {
+  if (!$g_nopassword && strlen($PGPASSWORD) == 0) {
     // Be careful, password will appear in clear text on the terminal...
     // At least, it won't show up in ps output :-/
     echo "Password: ";
@@ -68,6 +68,10 @@ if (strlen("$PGPORT") > 0) {
 $DSN .= 'dbname='.$PGDATABASE.' '.
        'user='.$PGUSER;
 
+if (!$g_witholdlibpq) {
+  $DSN .= ' application_name=pgsnap';
+}
+
 if (strlen("$PGPASSWORD") > 0) {
   $DSN .= ' password='.$PGPASSWORD;
 }
@@ -77,6 +81,10 @@ $connection = @pg_connect($DSN);
 if (!$connection) {
   echo "Connection error !\n";
   echo "DSN is $DSN\n";
+  if (!$g_witholdlibpq) {
+    echo "Maybe you should try with --with-old-libpq option if you don't have";
+    echo " an uptodate libpq.\n";
+  }
   die();
 }
 
