@@ -1,7 +1,7 @@
 <?php
 
 /*
- * Copyright (c) 2008 Guillaume Lelarge <guillaume@lelarge.info>
+ * Copyright (c) 2008-2010 Guillaume Lelarge <guillaume@lelarge.info>
  *
  * Permission to use, copy, modify, and distribute this software for any
  * purpose with or without fee is hereby granted, provided that the above
@@ -53,7 +53,7 @@ $buffer .= '<div class="tblBasic">
 while ($row = pg_fetch_array($rows)) {
 $buffer .= tr().'
   <td>'.$row['dba'].'</td>
-  <td>'.$row['datname'].'</td>
+  <td title="'.$comments['databases'][$row['datname']].'">'.$row['datname'].'</td>
   <td>'.$row['size'].'</td>
   <td>'.$row['buffers'].'</td>
   <td>'.($row['buffers']*8192).'</td>
