@@ -1,7 +1,7 @@
 <?php
 
 /*
- * Copyright (c) 2008 Guillaume Lelarge <guillaume@lelarge.info>
+ * Copyright (c) 2008-2010 Guillaume Lelarge <guillaume@lelarge.info>
  *
  * Permission to use, copy, modify, and distribute this software for any
  * purpose with or without fee is hereby granted, provided that the above
@@ -16,7 +16,7 @@
  * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  */
 
-$VERSION = '0.4.0';
+$VERSION = '0.6.0';
 
 $PGHOST = getenv('PGHOST');
 
@@ -34,10 +34,13 @@ if (strlen("$PGDATABASE") == 0) {
 
 $PGPASSWORD = getenv('PGPASSWORD');
 $g_passwordrequired = false;
+$g_nopassword = false;
 $g_withoutsysobjects = false;
 $g_alldatabases = false;
 $g_deleteifexists = false;
+$g_witholdlibpq = false;
 $outputdir = '';
+$queriesinlogs = false;
 
 for ($i = 1; $i < $_SERVER["argc"]; $i++) {
   switch($_SERVER["argv"][$i]) {
@@ -62,9 +65,22 @@ for ($i = 1; $i < $_SERVER["argc"]; $i++) {
     case "--database":
       $PGDATABASE = $_SERVER['argv'][++$i];
       break;
+    case "-w":
+    case "--no-password":
+      if ($g_passwordrequired) {
+        die("-w and -W parameters are mutually exclusive.\n");
+      }
+      $g_nopassword = true;
+      break;
     case "-W":
+      if ($g_nopassword) {
+        die("-w and -W parameters are mutually exclusive.\n");
+      }
       $g_passwordrequired = true;
       break;
+    case "--with-old-libpq":
+      $g_witholdlibpq = true;
+      break;
     case "-o":
     case "--output-dir":
       if ($g_alldatabases) {
@@ -86,6 +102,9 @@ for ($i = 1; $i < $_SERVER["argc"]; $i++) {
     case "--delete-if-exists":
       $g_deleteifexists = true;
       break;
+    case "--query-in-logs":
+      $queriesinlogs = true;
+      break;
     case "-?":
     case "-h":
     case "--help":
@@ -101,6 +120,8 @@ General options:
                   (default: "<?= $PGDATABASE ?>")
   -o outputdir    specify output directory
                   (default: "<?= $outputdir ?>")
+  --with-old-libpq
+                  disable the use of the parameter application_name
   -S, --without-sysobjects
                   get report without system objects informations
   --delete-if-exists
@@ -114,6 +135,7 @@ Connection options:
   -p PORT         database server port (default: "<?= $PGPORT ?>")
   -U NAME         database user name (default: "<?= $PGUSER ?>")
   -W              prompt for password
+  -w              don't prompt for password
 
 <?php
       exit;
