@@ -1,7 +1,7 @@
 <?php
 
 /*
- * Copyright (c) 2008 Guillaume Lelarge <guillaume@lelarge.info>
+ * Copyright (c) 2008-2010 Guillaume Lelarge <guillaume@lelarge.info>
  *
  * Permission to use, copy, modify, and distribute this software for any
  * purpose with or without fee is hereby granted, provided that the above
@@ -65,7 +65,7 @@ $buffer .= '
 
 while ($row = pg_fetch_array($rows)) {
 $buffer .= tr()."
-  <td>".$row['lanname']."</td>";
+  <td title=\"".$comments['languages'][$row['lanname']]."\">".$row['lanname']."</td>";
 if ($g_version == '83') {
   $buffer .= "
   <td>".$row['owner']."</td>";
