@@ -1,7 +1,7 @@
 <?php
 
 /*
- * Copyright (c) 2008 Guillaume Lelarge <guillaume@lelarge.info>
+ * Copyright (c) 2008-2010 Guillaume Lelarge <guillaume@lelarge.info>
  *
  * Permission to use, copy, modify, and distribute this software for any
  * purpose with or without fee is hereby granted, provided that the above
@@ -32,7 +32,8 @@ $query .= "
  CASE WHEN datname IS NOT NULL THEN datname
       ELSE database::text
  END AS database,
- relation::regclass as relation,";
+ nspname,
+ relname,";
 if ($g_version > 80) {
   $query .= "
  page,
@@ -59,7 +60,9 @@ $query .= "
  mode,
  granted
 FROM pg_locks
- LEFT JOIN pg_database ON pg_database.oid = database";
+ LEFT JOIN pg_database ON pg_database.oid = database
+ LEFT JOIN pg_class ON pg_class.oid = relation
+ LEFT JOIN pg_namespace ON pg_namespace.oid=pg_class.relnamespace";
 
 $rows = pg_query($connection, $query);
 if (!$rows) {
@@ -113,8 +116,18 @@ if ($g_version > 80) {
   <td>".$row['locktype']."</td>";
 }
 $buffer .= "
-  <td>".$row['database']."</td>
-  <td>".$row['relation']."</td>";
+  <td";
+if (array_key_exists($row['database'], $comments['databases'])) {
+  $buffer .= " title=\"".$comments['databases'][$row['database']]."\"";
+}
+$buffer .= ">".$row['database']."</td>
+  <td";
+if (array_key_exists($row['nspname'], $comments['relations'])) {
+  if (array_key_exists($row['relname'], $comments['relations'][$row['nspname']])) {
+    $buffer .= " title=\"".$comments['relations'][$row['nspname']][$row['relname']]."\"";
+  }
+}
+$buffer .= ">".$row['nspname'].".".$row['relname']."</td>";
 if ($g_version > 80) {
   $buffer .= "
   <td>".$row['page']."</td>
