@@ -1,7 +1,7 @@
 <?php
 
 /*
- * Copyright (c) 2008 Guillaume Lelarge <guillaume@lelarge.info>
+ * Copyright (c) 2008-2010 Guillaume Lelarge <guillaume@lelarge.info>
  *
  * Permission to use, copy, modify, and distribute this software for any
  * purpose with or without fee is hereby granted, provided that the above
@@ -28,9 +28,10 @@ $navigate_general = $navigate_header.'
       <li><a href="ver.html">Installed products</a></li>
       <li><a href="pgconfig.html">pg_config</a></li>
       <li><a href="pgcontroldata.html">pg_controldata</a></li>
-      <li><a href="param.html">General configuration</a></li>';
+      <li><a href="param.html">General configuration</a></li>
+      <li><a href="nondefaultparam.html">Non Default configuration</a></li>';
 
-if ($g_version > '80') {
+if ($g_version > '80' && $g_version < '84') {
   $navigate_general .= '
       <li><a href="paramautovac.html">Autovacuum configuration</a></li>';
 }
@@ -77,6 +78,10 @@ if ($g_version > '80') {
 $navigate_globalobjects.= '
       <li><a href="user1.html">Users\' Objects</a></li>
       <li><a href="user2.html">Users Space allocated</a></li>';
+if ($g_version >= '90') {
+  $navigate_globalobjects.= '
+      <li><a href="dbrolesettings.html">DB/Role Settings</a></li>';
+}
 if ($g_version > '74') {
   $navigate_globalobjects.= '
       <li><a href="tablespaces.html">Tablespaces</a></li>';
@@ -85,9 +90,10 @@ if ($g_version > '74') {
       <li><a href="graph_tblspcsize.html">Tablespaces Size Graph</a></li>';
   }
   $navigate_globalobjects.= '
-      <li class="last-child"><a href="tblspc1.html">Tablespaces\' objects</a></li>';
+      <li><a href="tblspc1.html">Tablespaces\' objects</a></li>';
 }
 $navigate_globalobjects.= '
+      <li class="last-child"><a href="largeobjects.html">Large Objects</a></li>
     </ul>
   </div>
 </div>
@@ -95,7 +101,12 @@ $navigate_globalobjects.= '
 
 $navigate_dbobjects = $navigate_header.'
     <ul>
-      <li><a href="schemas.html">Schemas</a></li>
+      <li><a href="schemas.html">Schemas</a></li>';
+if ($g_version >= '90') {
+  $navigate_dbobjects.= '
+      <li><a href="defaultacl.html">Default ACLs</a></li>';
+}
+$navigate_dbobjects.= '
       <li><a href="tables.html">Tables</a></li>';
 
 if ($g_flashexists && $g_version > '80') {
@@ -115,9 +126,11 @@ if ($g_pgstattuple) {
 $navigate_dbobjects .= '
       <li><a href="tableswithoutpkey.html">Tables Without PKEY</a></li>
       <li><a href="tableswith5+indexes.html">Tables With 5+ indexes</a></li>
+      <li><a href="clusteredtables.html">Clustered Tables</a></li>
       <li><a href="fkconstraints.html">Tables With FKEY constraints</a></li>
       <li><a href="views.html">Views</a></li>
       <li><a href="sequences.html">Sequences</a></li>
+      <li><a href="sequences2.html">Sequences - metadata</a></li>
       <li><a href="indexes.html">Indexes</a></li>';
 
 if ($g_version > '80') {
@@ -125,6 +138,11 @@ if ($g_version > '80') {
       <li><a href="indexesbiggerthantables.html">Indexes Bigger Than Tables</a></li>';
 }
 
+if ($g_version > '82') {
+  $navigate_dbobjects .= '
+      <li><a href="uselessindexes.html">Useless Indexes</a></li>';
+}
+
 if ($g_pgstatindex) {
   $navigate_dbobjects .= '
       <li><a href="fragmentedindexes.html">Fragmented Indexes</a></li>';
@@ -158,7 +176,11 @@ $navigate_activities .= '
       <li><a href="locks.html">Locks</a></li>';
 if ($g_version > '80') {
   $navigate_activities .= '
-      <li class="last-child"><a href="exclusivelocks.html">Exclusive Locks</a></li>';
+      <li><a href="exclusivelocks.html">Exclusive Locks</a></li>';
+}
+if ($g_version < '90') {
+  $navigate_activities .= '
+      <li class="last-child"><a href="listeners.html">Listeners</a></li>';
 }
 $navigate_activities .= '
     </ul>
@@ -200,7 +222,12 @@ if ($g_fsmpages) {
 $navigate_stats .= '
       <li><a href="stat_indexes.html">Indexes (Tuples)</a></li>
       <li><a href="statio_indexes.html">Indexes (IO)</a></li>
-      <li class="last-child"><a href="statio_sequences.html">Sequences (IO)</a></li>
+      <li><a href="statio_sequences.html">Sequences (IO)</a></li>';
+if ($g_version >= '84') {
+  $navigate_stats .= '
+      <li><a href="stat_functions.html">Functions (Runs)</a></li>';
+}
+$navigate_stats .= '
     </ul>
   </div>
 </div>
