@@ -1,7 +1,7 @@
 <?php
 
 /*
- * Copyright (c) 2008 Guillaume Lelarge <guillaume@lelarge.info>
+ * Copyright (c) 2008-2010 Guillaume Lelarge <guillaume@lelarge.info>
  *
  * Permission to use, copy, modify, and distribute this software for any
  * purpose with or without fee is hereby granted, provided that the above
@@ -51,8 +51,8 @@ $buffer .= '<div class="tblBasic">
  
 while ($row = pg_fetch_array($rows)) {
 $buffer .= tr()."
-  <td>".$row['rolname']."</td>
-  <td>".$row['database']."</td>
+  <td title=\"".$comments['roles'][$row['rolname']]."\">".$row['rolname']."</td>
+  <td title=\"".$comments['databases'][$row['database']]."\">".$row['database']."</td>
   <td>".$row['transaction']."</td>
   <td>".$row['gid']."</td>
   <td>".$row['prepared']."</td>
