@@ -1,7 +1,7 @@
 <?php
 
 /*
- * Copyright (c) 2008 Guillaume Lelarge <guillaume@lelarge.info>
+ * Copyright (c) 2008-2010 Guillaume Lelarge <guillaume@lelarge.info>
  *
  * Permission to use, copy, modify, and distribute this software for any
  * purpose with or without fee is hereby granted, provided that the above
@@ -45,11 +45,19 @@ $query .= "
   relisshared,
   relkind,
   relnatts,
-  relchecks,
+  relchecks,";
+if ($g_version < 84) {
+  $query .= "
   reltriggers,
   relukeys,
   relfkeys,
-  relrefs,
+  relrefs,";
+}
+else {
+  $query .= "
+  relistemp,";
+}
+$query .= "
   relhasoids,
   relhaspkey,
   relhasrules,
@@ -94,7 +102,7 @@ $buffer .= '<div class="tblBasic">
 
 <table border="0" cellpadding="0" cellspacing="0" class="tblBasicGrey">
 <tr>
-  <th class="colFirst">Table name</th>
+  <th class="colFirst">Sequence name</th>
   <th class="colMid">Schema name</th>
   <th class="colMid">Table Owner</th>
   <th class="colMid">relam</th>
@@ -111,12 +119,19 @@ $buffer .= '
   <th class="colMid">Has index?</th>
   <th class="colMid">Is shared?</th>
   <th class="colMid">Kind</th>
-  <th class="colMid">natts</th>
-  <th class="colMid">Checks</th>
+  <th class="colMid">Number of Attributes</th>
+  <th class="colMid">Checks</th>';
+if ($g_version < 84) {
+$buffer .= '
   <th class="colMid">Triggers</th>
   <th class="colMid">Unique Keys</th>
   <th class="colMid">Foreign Keys</th>
-  <th class="colMid">Refs</th>
+  <th class="colMid">Refs</th>';
+} else {
+$buffer .= '
+  <th class="colMid">Is Temp</th>';
+}
+$buffer .= '
   <th class="colMid">Has OID?</th>
   <th class="colMid">Has Primary Key?</th>
   <th class="colMid">Has Rules?</th>
@@ -145,9 +160,9 @@ $buffer .= '
 
 while ($row = pg_fetch_array($rows)) {
 $buffer .= tr($row['schema'])."
-  <td>".$row['relname']."</td>
-  <td>".$row['schema']."</td>
-  <td>".$row['owner']."</td>
+  <td title=\"".$comments['relations'][$row['schema']][$row['relname']]."\">".$row['relname']."</td>
+  <td title=\"".$comments['schemas'][$row['schema']]."\">".$row['schema']."</td>
+  <td title=\"".$comments['roles'][$row['owner']]."\">".$row['owner']."</td>
   <td>".$row['relam']."</td>
   <td>".$row['relfilenode']."</td>
   <td>".$row['relpages']."</td>
@@ -156,13 +171,21 @@ $buffer .= tr($row['schema'])."
   <td>".$row['reltoastidxid']."</td>
   <td>".$row['relhasindex']."</td>
   <td>".$row['relisshared']."</td>
-  <td>".$row['relkind']."</td>
+  <td>".$kind[$row['relkind']]."</td>
   <td>".$row['relnatts']."</td>
-  <td>".$row['relchecks']."</td>
+  <td>".$row['relchecks']."</td>";
+if ($g_version < 84) {
+  $buffer .= "
   <td>".$row['reltriggers']."</td>
   <td>".$row['relukeys']."</td>
   <td>".$row['relfkeys']."</td>
-  <td>".$row['relrefs']."</td>
+  <td>".$row['relrefs']."</td>";
+}
+else {
+  $buffer .= "
+  <td>".$image[$row['relistemp']]."</td>";
+}
+$buffer .= "
   <td>".$row['relhasoids']."</td>
   <td>".$row['relhaspkey']."</td>
   <td>".$row['relhasrules']."</td>
@@ -177,9 +200,15 @@ if ($g_version >= 82) {
 $buffer .= "
  <td>".$row['reloptions']."</td>";
 }
-$buffer .= "
+if ($g_version > 80) {
+  $buffer .= "
   <td>".$row['size']."</td>
 </tr>";
+} else {
+  $buffer .= "
+  <td>".pretty_size($row['size'])."</td>
+</tr>";
+}
 }
 $buffer .= '</table>
 </div>
