@@ -1,7 +1,7 @@
 <?php
 
 /*
- * Copyright (c) 2008 Guillaume Lelarge <guillaume@lelarge.info>
+ * Copyright (c) 2008-2010 Guillaume Lelarge <guillaume@lelarge.info>
  *
  * Permission to use, copy, modify, and distribute this software for any
  * purpose with or without fee is hereby granted, provided that the above
@@ -29,7 +29,12 @@ if(!$g_withoutsysobjects) {
 $query = "SELECT
   relname,
   nspname AS schema,
-  pg_get_userbyid(relowner) AS owner,
+  pg_get_userbyid(relowner) AS owner,";
+if ($g_version >= 90) {
+  $query .= "
+  reloftype,";
+}
+$query .= "
   relam,
   relfilenode,";
 if ($g_version > 74) {
@@ -45,13 +50,26 @@ $query .= "
   relisshared,
   relkind,
   relnatts,
-  relchecks,
+  relchecks,";
+if ($g_version < 84) {
+  $query .= "
   reltriggers,
   relukeys,
   relfkeys,
-  relrefs,
+  relrefs,";
+}
+else {
+  $query .= "
+  relistemp,";
+}
+$query .= "
   relhasoids,
-  relhaspkey,
+  relhaspkey,";
+if ($g_version >= 90) {
+  $query .= "
+  relhasexclusion,";
+}
+$query .= "
   relhasrules,
   relhassubclass,";
 if ($g_version >= 82) {
@@ -96,7 +114,12 @@ $buffer .= '<div class="tblBasic">
 <tr>
   <th class="colFirst">Table name</th>
   <th class="colMid">Schema name</th>
-  <th class="colMid">Table Owner</th>
+  <th class="colMid">Table Owner</th>';
+if ($g_version >= 90) {
+  $buffer .= '
+  <th class="colMid">Of Type</th></th>';
+}
+$buffer .= '
   <th class="colMid">relam</th>
   <th class="colMid">relfilenode</th>';
 if ($g_version > 74) {
@@ -111,14 +134,26 @@ $buffer .= '
   <th class="colMid">Has index?</th>
   <th class="colMid">Is shared?</th>
   <th class="colMid">Kind</th>
-  <th class="colMid">natts</th>
-  <th class="colMid">Checks</th>
+  <th class="colMid">Number of Attributes</th>
+  <th class="colMid">Checks</th>';
+if ($g_version < 84) {
+$buffer .= '
   <th class="colMid">Triggers</th>
   <th class="colMid">Unique Keys</th>
   <th class="colMid">Foreign Keys</th>
-  <th class="colMid">Refs</th>
+  <th class="colMid">Refs</th>';
+} else {
+$buffer .= '
+  <th class="colMid">Is Temp</th>';
+}
+$buffer .= '
   <th class="colMid">Has OID?</th>
-  <th class="colMid">Has Primary Key?</th>
+  <th class="colMid">Has Primary Key?</th>';
+if ($g_version >= 90) {
+  $buffer .= '
+  <th class="colMid">Has Exclusion Constraint</th>';
+}
+$buffer .= '
   <th class="colMid">Has Rules?</th>
   <th class="colMid">Has subclass?</th>';
 if ($g_version >= 82) {
@@ -144,9 +179,14 @@ $buffer .= '
 
 while ($row = pg_fetch_array($rows)) {
 $buffer .= tr($row['schema'])."
-  <td>".$row['relname']."</td>
-  <td>".$row['schema']."</td>
-  <td>".$row['owner']."</td>
+  <td title=\"".$comments['relations'][$row['schema']][$row['relname']]."\">".$row['relname']."</td>
+  <td title=\"".$comments['schemas'][$row['schema']]."\">".$row['schema']."</td>
+  <td title=\"".$comments['roles'][$row['owner']]."\">".$row['owner']."</td>";
+if ($g_version >= 90) {
+  $buffer .= "
+  <td>".$row['reloftype']."</td>";
+}
+$buffer .= "
   <td>".$row['relam']."</td>
   <td>".$row['relfilenode']."</td>";
 if ($g_version > 74) {
@@ -160,15 +200,28 @@ $buffer .= "
   <td>".$row['reltoastidxid']."</td>
   <td>".$image[$row['relhasindex']]."</td>
   <td>".$image[$row['relisshared']]."</td>
-  <td>".$row['relkind']."</td>
+  <td>".$kind[$row['relkind']]."</td>
   <td>".$row['relnatts']."</td>
-  <td>".$row['relchecks']."</td>
+  <td>".$row['relchecks']."</td>";
+if ($g_version < 84) {
+  $buffer .= "
   <td>".$row['reltriggers']."</td>
   <td>".$row['relukeys']."</td>
   <td>".$row['relfkeys']."</td>
-  <td>".$row['relrefs']."</td>
+  <td>".$row['relrefs']."</td>";
+}
+else {
+  $buffer .= "
+  <td>".$image[$row['relistemp']]."</td>";
+}
+$buffer .= "
   <td>".$image[$row['relhasoids']]."</td>
-  <td>".$image[$row['relhaspkey']]."</td>
+  <td>".$image[$row['relhaspkey']]."</td>";
+if ($g_version >= 90) {
+  $buffer .= "
+  <td>".$image[$row['relhasexclusion']]."</td>";
+}
+$buffer .= "
   <td>".$image[$row['relhasrules']]."</td>
   <td>".$image[$row['relhassubclass']]."</td>";
 if ($g_version >= 82) {
@@ -181,9 +234,15 @@ if ($g_version >= 82) {
 $buffer .= "
  <td>".$row['reloptions']."</td>";
 }
-$buffer .= "
+if ($g_version > 80) {
+  $buffer .= "
   <td>".$row['size']."</td>
 </tr>";
+} else {
+  $buffer .= "
+  <td>".pretty_size($row['size'])."</td>
+</tr>";
+}
 }
 $buffer .= '</table>
 </div>
