@@ -1,7 +1,7 @@
 <?php
 
 /*
- * Copyright (c) 2008 Guillaume Lelarge <guillaume@lelarge.info>
+ * Copyright (c) 2008-2010 Guillaume Lelarge <guillaume@lelarge.info>
  *
  * Permission to use, copy, modify, and distribute this software for any
  * purpose with or without fee is hereby granted, provided that the above
@@ -24,8 +24,15 @@ $buffer = $navigate_globalobjects.'
 
 $query = "SELECT spcname,
   pg_get_userbyid(spcowner) AS owner,
-  spclocation,
+  CASE WHEN length(spclocation) = 0
+       THEN (SELECT setting FROM pg_settings WHERE name='data_directory')
+       ELSE spclocation
+  END AS spclocation,
   spcacl";
+if ($g_version >= 90) {
+    $query .= ', spcoptions
+  ';
+}
 if ($g_superuser) {
   if ($g_version > 80) {
     $query .= ',
@@ -60,6 +67,13 @@ if ($g_superuser) {
     $buffer .= '
   <th class="colMid" width="200">Estimated Size</th>';
   }
+  $colspan = 5;
+} else {
+  $colspan = 4;
+}
+if ($g_version >= 90) {
+  $buffer .= '
+  <th class="colMid" width="20%">Configuration</th>';
 }
 $buffer .= '
   <th class="colLast" width="20%">ACL</th>
@@ -67,17 +81,40 @@ $buffer .= '
 ';
 
 while ($row = pg_fetch_array($rows)) {
-  $buffer .= tr()."
-  <td>".$row['owner']."</td>
-  <td>".$row['spcname']."</td>
+  $buffer .= tr().'
+  <td title="'.$comments['roles'][$row['owner']].'">'.$row['owner'].'</td>
+  <td title="'.$comments['tablespaces'][$row['spcname']].'">'.$row['spcname']."</td>
   <td>".$row['spclocation']."</td>";
   if ($g_superuser) {
-    $buffer .= "
+    if ($g_version > 80) {
+      $buffer .= "
   <td>".$row['size']."</td>";
+    } else {
+      $buffer .= "
+  <td>".pretty_size($row['size'])."</td>";
+    }
+  }
+  if ($g_version >= 90) {
+    $buffer .= '
+  <td>'.$row['spcoptions'].'</td>';
   }
   $buffer .= "
   <td>".$row['spcacl']."</td>
 </tr>";
+  if (!strcmp($PGHOST, '127.0.0.1') || !strcmp($PGHOST, 'localhost')
+    || strlen($PGHOST) == 0 || preg_match('/^\//', $PGHOST) == 1) {
+    if (strlen($row['spclocation']) > 0) {
+      exec('df -P '.$row['spclocation']." | sed 's/ \+/ /g'", $partitions);
+      $partition = $partitions[count($partitions) -1];
+      $infospartition = split (' ', $partition);
+      $message = $infospartition[0]." mounted on ".$infospartition[5].",
+".$infospartition[3]." free bytes (".$infospartition[4]." free)";
+      $buffer .= tr()."
+  <td>&nbsp;</td>
+  <td colspan='".$colspan."'>".$message."</td>
+";
+    }
+  }
 }
 $buffer .= '</table>
 </div>
