@@ -1,7 +1,7 @@
 <?php
 
 /*
- * Copyright (c) 2008 Guillaume Lelarge <guillaume@lelarge.info>
+ * Copyright (c) 2008-2010 Guillaume Lelarge <guillaume@lelarge.info>
  *
  * Permission to use, copy, modify, and distribute this software for any
  * purpose with or without fee is hereby granted, provided that the above
@@ -78,10 +78,17 @@ if ($g_version > 80) {
 
 while ($row = pg_fetch_array($rows)) {
 $buffer .= tr($row['nspname'])."
-  <td>".$row['owner']."</td>
-  <td>".$row['nspname']."</td>
-  <td>".$row['relname']."</td>
-  <td>".$row['size']."</td>
+  <td title=\"".$comments['roles'][$row['owner']]."\">".$row['owner']."</td>
+  <td title=\"".$comments['schemas'][$row['nspname']]."\">".$row['nspname']."</td>
+  <td title=\"".$comments['relations'][$row['nspname']][$row['relname']]."\">".$row['relname']."</td>";
+if ($g_version > 80) {
+$buffer .= "
+  <td>".$row['size']."</td>";
+} else {
+$buffer .= "
+  <td>".pretty_size($row['size'])."</td>";
+}
+$buffer .= "
 </tr>";
 }
 
