@@ -1,7 +1,7 @@
 <?php
 
 /*
- * Copyright (c) 2008 Guillaume Lelarge <guillaume@lelarge.info>
+ * Copyright (c) 2008-2010 Guillaume Lelarge <guillaume@lelarge.info>
  *
  * Permission to use, copy, modify, and distribute this software for any
  * purpose with or without fee is hereby granted, provided that the above
@@ -75,9 +75,16 @@ $buffer .= '
 
 while ($row = pg_fetch_array($rows)) {
 $buffer .= tr().'
-  <td>'.$row['rolname'].'</td>
-  <td>'.ucfirst($row['kind']).'</td>
-  <td>'.$row['size'].'</td>
+  <td title="'.$comments['roles'][$row['rolname']].'">'.$row['rolname'].'</td>
+  <td>'.ucfirst($row['kind']).'</td>';
+if ($g_version > 80) {
+$buffer .= '
+  <td>'.$row['size'].'</td>';
+} else {
+$buffer .= '
+  <td>'.pretty_size($row['size']).'</td>';
+}
+$buffer .= '
 </tr>';
 }
 $buffer .= '</table>
