@@ -1,7 +1,7 @@
 <?php
 
 /*
- * Copyright (c) 2008 Guillaume Lelarge <guillaume@lelarge.info>
+ * Copyright (c) 2008-2010 Guillaume Lelarge <guillaume@lelarge.info>
  *
  * Permission to use, copy, modify, and distribute this software for any
  * purpose with or without fee is hereby granted, provided that the above
@@ -45,11 +45,15 @@ $query .= "
   relisshared,
   relkind,
   relnatts,
-  relchecks,
+  relchecks,";
+if ($g_version < 84) {
+  $query .= "
   reltriggers,
   relukeys,
   relfkeys,
-  relrefs,
+  relrefs,";
+}
+$query .= "
   relhasoids,
   relhaspkey,
   relhasrules,
@@ -112,11 +116,15 @@ $buffer .= '
   <th class="colMid">Is shared?</th>
   <th class="colMid">Kind</th>
   <th class="colMid">natts</th>
-  <th class="colMid">Checks</th>
+  <th class="colMid">Checks</th>';
+if ($g_version < 84) {
+$buffer .= '
   <th class="colMid">Triggers</th>
   <th class="colMid">Unique Keys</th>
   <th class="colMid">Foreign Keys</th>
-  <th class="colMid">Refs</th>
+  <th class="colMid">Refs</th>';
+}
+$buffer .= '
   <th class="colMid">Has OID?</th>
   <th class="colMid">Has Primary Key?</th>
   <th class="colMid">Has Rules?</th>
@@ -163,11 +171,15 @@ $buffer .= "
   <td>".$image[$row['relisshared']]."</td>
   <td>".$row['relkind']."</td>
   <td>".$row['relnatts']."</td>
-  <td>".$row['relchecks']."</td>
+  <td>".$row['relchecks']."</td>";
+if ($g_version < 84) {
+  $buffer .= "
   <td>".$row['reltriggers']."</td>
   <td>".$row['relukeys']."</td>
   <td>".$row['relfkeys']."</td>
-  <td>".$row['relrefs']."</td>
+  <td>".$row['relrefs']."</td>";
+}
+$buffer .= "
   <td>".$image[$row['relhasoids']]."</td>
   <td>".$image[$row['relhaspkey']]."</td>
   <td>".$image[$row['relhasrules']]."</td>
@@ -182,9 +194,15 @@ if ($g_version >= 82) {
 $buffer .= "
  <td>".$row['reloptions']."</td>";
 }
-$buffer .= "
+if ($g_version > 80) {
+  $buffer .= "
   <td>".$row['size']."</td>
 </tr>";
+} else {
+  $buffer .= "
+  <td>".pretty_size($row['size'])."</td>
+</tr>";
+}
 }
 $buffer .= '</table>
 </div>
