@@ -2,7 +2,7 @@
 <?php
 
 /*
- * Copyright (c) 2008 Guillaume Lelarge <guillaume@lelarge.info>
+ * Copyright (c) 2008-2010 Guillaume Lelarge <guillaume@lelarge.info>
  *
  * Permission to use, copy, modify, and distribute this software for any
  * purpose with or without fee is hereby granted, provided that the above
@@ -32,6 +32,11 @@ if ($g_alldatabases) {
   echo "Connecting...\n";
   include 'lib/connect.php';
 
+  if (!$queriesinlogs) {
+    $query = "SET log_statement TO 'none'; SET log_duration TO off; SET log_min_duration_statement TO -1;";
+    pg_query($connection, $query);
+  }
+
   $query = "SELECT datname FROM pg_database WHERE datallowconn IS TRUE";
   $rows = pg_query($connection, $query);
   if (!$rows) {
